"""
This package handles ISO639-3 language codes.

The data is loaded directly from the tabular data made available from the
managing organization https://iso639-3.sil.org/code_tables/download_tables

The data is loaded at import time from a pickled object, if available.
Otherwise, the tabular file is looked for and if found, data is loaded and
pickled.

You can update the database by removing the pickled object and replacing the
tabular data file with an updated one.
"""
import os
import json
import csv

PICKLED_STORE = "iso639_3_20220311.py"
CSV_STORE = "iso-639-3-20220311.tab"
FIELDNAMES = ['alpha_3', 'Part2B', 'Part2T', 'alpha_2', 'Scope', 'Language_Type', 'name', 'Comment']

if __name__ == "__main__":
    this_dir, this_filename = os.path.split(__file__)  # Get path
    csv_store_path = os.path.join(this_dir, CSV_STORE)
    pickled_store_path = os.path.join(this_dir, PICKLED_STORE)
    with open(csv_store_path) as csvfile:
        dialect = csv.Sniffer().sniff(csvfile.read(1024))
        csvfile.seek(0)
        languages_raw = [l for l in csv.DictReader(csvfile, fieldnames=FIELDNAMES, dialect=dialect)]
        languages_raw.pop(0) #discard header

    with open(pickled_store_path, 'w') as pickle_file:
        pickle_file.write(f"LANGUAGES=\"\"\"{json.dumps(languages_raw)}\"\"\"")